## 0.0.46

This new version includes a significant refactor of the tutorialbot, improving its flexibility and maintainability.

### New Features

- The tutorialbot has been refactored from a SimpleBot instance to a function that returns a SimpleBot instance. This change enhances the flexibility of the bot, allowing for more diverse use cases. (d85426) (Eric Ma)

### Bug Fixes

- No bug fixes in this release.

### Deprecations

- No deprecations in this release.
